@@ -1,4 +1,5 @@
-/* Copyright (C) 1988, 1989, 1990, 1991, 1992 Free Software Foundation, Inc.
+/* Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993
+	Free Software Foundation, Inc.
 This file is part of GNU Make.
 
 GNU Make is free software; you can redistribute it and/or modify
@@ -57,15 +58,15 @@ struct file
 
     unsigned int double_colon:1;/* Nonzero for double-colon entry */
     unsigned int precious:1;	/* Non-0 means don't delete file on quit */
-    unsigned int tried_implicit:1;/* Nonzero if have searched
-				     for implicit rule for making
-				     this file; don't search again.  */
+    unsigned int tried_implicit:1; /* Nonzero if have searched
+				      for implicit rule for making
+				      this file; don't search again.  */
     unsigned int updating:1;	/* Nonzero while updating deps of this file */
     unsigned int updated:1;	/* Nonzero if this file has been remade.  */
     unsigned int is_target:1;	/* Nonzero if file is described as target.  */
     unsigned int cmd_target:1;	/* Nonzero if file was given on cmd line.  */
     unsigned int phony:1;	/* Nonzero if this is a phony file
-				   ie, a dependent of .PHONY.  */
+				   i.e., a dependency of .PHONY.  */
     unsigned int intermediate:1;/* Nonzero if this is an intermediate file.  */
     unsigned int dontcare:1;	/* Nonzero if no complaint is to be made if
 				   this target cannot be remade.  */
@@ -89,6 +90,17 @@ extern time_t f_mtime ();
 #define file_mtime(f) file_mtime_1 ((f), 1)
 #define file_mtime_no_search(f) file_mtime_1 ((f), 0)
 
+/* Modtime value to use for `infinitely new'.  We used to get the current time
+   from the system and use that whenever we wanted `new'.  But that causes
+   trouble when the machine running make and the machine holding a file have
+   different ideas about what time it is; and can also lose for `force'
+   targets, which need to be considered newer than anything that depends on
+   them, even if said dependents' modtimes are in the future.
+
+   NOTE: This assumes 32-bit `time_t's, but I cannot think of a portable way
+   to produce the largest representable integer of a given signed type.  */
+#define NEW_MTIME	((time_t) 0x7fffffff)
+
 
 #define check_renamed(file) \
   while ((file)->renamed != 0) (file) = (file)->renamed /* No ; here.  */
