@@ -21,7 +21,10 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
  #pragma alloca
 #endif
 
-#include "config.h"
+/* We use <config.h> instead of "config.h" so that a compilation
+   using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
+   (which it would do because make.h was found in $srcdir).  */
+#include <config.h>
 #undef	HAVE_CONFIG_H
 #define HAVE_CONFIG_H
 
@@ -37,6 +40,12 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include <signal.h>
 #include <stdio.h>
 #include <ctype.h>
+#ifdef HAVE_SYS_TIMEB_H
+/* SCO 3.2 "devsys 4.2" has a prototype for `ftime' in <time.h> that bombs
+   unless <sys/timeb.h> has been included first.  Does every system have a
+   <sys/timeb.h>?  If any does not, configure should check for it.  */
+#include <sys/timeb.h>
+#endif
 #include <time.h>
 #include <errno.h>
 
@@ -62,6 +71,10 @@ extern int errno;
 #undef POSIX
 #endif
 
+#if !defined (POSIX) && defined (_AIX) && defined (_POSIX_SOURCE)
+#define POSIX
+#endif
+
 #if !defined (HAVE_SYS_SIGLIST) && defined (HAVE__SYS_SIGLIST)
 #define	sys_siglist	_sys_siglist
 #define	HAVE_SYS_SIGLIST	/* Now we have it.  */
@@ -257,9 +270,9 @@ extern void file_impossible ();
 extern char *dir_name ();
 
 extern void define_default_variables ();
-extern void set_default_suffixes (), install_default_implicit_rules ();
-extern void convert_to_pattern (), count_implicit_rule_limits ();
-extern void create_pattern_rule ();
+extern void set_default_suffixes (), install_default_suffix_rules ();
+extern void install_default_implicit_rules (), count_implicit_rule_limits ();
+extern void convert_to_pattern (), create_pattern_rule ();
 
 extern void build_vpath_lists (), construct_vpath_list ();
 extern int vpath_search ();
@@ -315,6 +328,7 @@ extern double max_load_average;
 extern char *program;
 extern char *starting_directory;
 extern unsigned int makelevel;
+extern char *version_string, *remote_description;
 
 extern unsigned int commands_started;
 
