@@ -267,19 +267,30 @@ makefile_fatal (file, lineno, s1, s2, s3, s4, s5, s6)
   die (1);
 }
 
+#ifndef HAVE_STRERROR
+char *
+strerror (errnum)
+     int errnum;
+{
+  extern int errno, sys_nerr;
+  extern char *sys_errlist[];
+  static char buf[] = "Unknown error 12345678901234567890";
+
+  if (errno < sys_nerr)
+    return sys_errlist[errnum];
+
+  sprintf ("Unknown error %d", buf, errnum);
+  return buf;
+}
+#endif
+
 /* Print an error message from errno.  */
 
 void
 perror_with_name (str, name)
      char *str, *name;
 {
-  extern int errno, sys_nerr;
-  extern char *sys_errlist[];
-
-  if (errno < sys_nerr)
-    error ("%s%s: %s", str, name, sys_errlist[errno]);
-  else
-    error ("%s%s: Unknown error %d", str, name, errno);
+  error ("%s%s: %s", str, name, strerror (errno));
 }
 
 /* Print an error message from errno and exit.  */
@@ -288,13 +299,7 @@ void
 pfatal_with_name (name)
      char *name;
 {
-  extern int errno, sys_nerr;
-  extern char *sys_errlist[];
-
-  if (errno < sys_nerr)
-    fatal ("%s: %s", name, sys_errlist[errno]);
-  else
-    fatal ("%s: Unknown error %d", name, errno);
+  fatal ("%s: %s", name, strerror (errno));
 
   /* NOTREACHED */
 }
@@ -509,9 +514,13 @@ log_access (flavor)
   if (! debug_flag)
     return;
 
-  printf ("%s access: user %d (real %d), group %d (real %d)\n",
-	  flavor, geteuid (), getuid (), getegid (), getgid ());
-  fflush (stdout);
+  /* All the other debugging messages go to stdout,
+     but we write this one to stderr because it might be
+     run in a child fork whose stdout is piped.  */
+
+  fprintf (stderr, "%s access: user %d (real %d), group %d (real %d)\n",
+	   flavor, geteuid (), getuid (), getegid (), getgid ());
+  fflush (stderr);
 }
 
 
